@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to hundreds of possible chord progressions
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use strict;
 use warnings;
@@ -99,7 +99,7 @@ Data::Dataset::ChordProgressions - Provide access to hundreds of possible chord
 
 =head1 VERSION
 
-version 0.0302
+version 0.0303
 
 =head1 SYNOPSIS
 
@@ -158,12 +158,12 @@ Return the chord progression data as a hash.
 Transpose a B<progression> in the key of C<C> to the given B<note> and
 B<scale>.
 
-The progression must be a string of hyphen-separated chord
-names. For example: C<'C-F-Am-F'>
+The progression must be a string of hyphen-separated chord names. For
+example: C<'C-F-Am-F'>
 
-=head2 SEE ALSO
+=head1 SEE ALSO
 
-The F<t/01-functions.t> file
+The F<t/01-functions.t> and F<eg/*> files
 
 L<Exporter>
 
